tcg/tcg.h: fix a few typos

Signed-off-by: Aurelien Jarno <aurelien@aurel32.net>

git-svn-id: svn://svn.savannah.nongnu.org/qemu/trunk@7024 c046a42c-6fe2-441c-8c8c-71466251a162
diff --git a/tcg/tcg.h b/tcg/tcg.h
index c9b001e..bf95d7e 100644
--- a/tcg/tcg.h
+++ b/tcg/tcg.h
@@ -174,13 +174,13 @@
 #define TCG_CALL_TYPE_REGPARM_1 0x0001 /* i386 style regparm call (1 reg) */
 #define TCG_CALL_TYPE_REGPARM_2 0x0002 /* i386 style regparm call (2 regs) */
 #define TCG_CALL_TYPE_REGPARM   0x0003 /* i386 style regparm call (3 regs) */
 /* A pure function only reads its arguments and TCG globals variables
    and cannot raise exceptions. Hence a call to a pure function can be
    safely suppressed if the return value is not used. */
 #define TCG_CALL_PURE           0x0010 
 /* A const function only reads its arguments and does not use TCG
-   globals variables. Hence a call to such a function does not
-   save TCG globals variabes back to their canonical location. */
+   global variables. Hence a call to such a function does not
+   save TCG global variables back to their canonical location. */
 #define TCG_CALL_CONST          0x0020
 
 /* used to align parameters */
@@ -174,13 +174,13 @@
 #define TCG_CALL_TYPE_REGPARM_2 0x0002 /* i386 style regparm call (2 regs) */
 #define TCG_CALL_TYPE_REGPARM   0x0003 /* i386 style regparm call (3 regs) */
-/* A pure function only reads its arguments and TCG globals variables
+/* A pure function only reads its arguments and TCG global variables
    and cannot raise exceptions. Hence a call to a pure function can be
    safely suppressed if the return value is not used. */